from setuptools import setup, find_packages

setup(
    name="dailylog",
    version='0.0.3',
    packages=find_packages(),
    description="record logs per day",
    long_description=open('README.md').read(),
    author="xinyang zhou",
    author_email='308885823@qq.com',
    url="https://github.com/darkwhale/dailylog",
    download_url='https://github.com/darkwhale/dailylog/archive/master.zip',
    keywords=['log', 'day'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries',
    ],
)
